<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://inspiredsoft.com
 * @since      1.0.0
 *
 * @package    Leadifly
 * @subpackage Leadifly/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Leadifly
 * @subpackage Leadifly/admin
 * @author     InspiredSoft <tech@inspiredsoft.com>
 */
class Leadifly_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Leadifly_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Leadifly_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if ( 'leadifly' == get_current_screen()->id ) {
		    wp_enqueue_style( 'wp-color-picker' );
            wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/leadifly-admin.css', array(), $this->version, 'all' );
        }

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Leadifly_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Leadifly_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if ( 'leadifly_page_leadify_settings' == get_current_screen()->id ) {
            wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/leadifly-admin.js', array( 'jquery' ), $this->version, true );
        }

	}

	public function add_plugin_admin_menu() {
	    add_options_page('Leadifly Settings', 'Leadifly Settings', 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page'));
	    add_menu_page('Leadifly', 'Leadifly', 'publish_posts', $this->plugin_name, array($this, 'add_leadifly_admin_menu'), plugin_dir_url(__DIR__) . 'admin/img/leadifly-icon.png');

        add_action('admin_menu', array($this, 'add_links_into_leadifly'), 99);

        require_once plugin_dir_path(__DIR__) . 'includes/settings.php';
    }

    public function add_links_into_leadifly() {
	    global $submenu;

	    $submenu[$this->plugin_name][] = array('Links', 'manage_options', 'edit.php?post_type=leadifly_link');
	    $submenu[$this->plugin_name][] = array('Subscribers', 'manage_options', 'edit.php?post_type=leadifly_subscriber');
	    $submenu[$this->plugin_name][] = array('Notifications', 'manage_options', 'edit.php?post_type=leadifly_notif');
        add_submenu_page($this->plugin_name, 'Settings', 'Settings', 'manage_options', 'leadify_settings', array($this, 'render_settings_page'));
	    $submenu[$this->plugin_name][] = array('Support', 'manage_options', 'http://inspiredsoft.com');

    }

    public function add_action_links( $links ) {
	    $settings_link = array(
            '<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __('Settings', $this->plugin_name) . '</a>',
        );
	    return array_merge( $settings_link, $links );
    }

    public function display_plugin_setup_page() {
	    include_once( 'partials/leadifly-admin-display.php' );
    }

    public function add_leadifly_admin_menu() {
        include_once( 'partials/leadifly-admin-links.php' );
    }

    public function options_update() {
	    register_setting($this->plugin_name, $this->plugin_name, array($this, 'validate'));
    }

    public function validate( $input ) {
	    $valid = array();

        $valid['cleanup'] = (isset($input['cleanup']) && !empty($input['cleanup'])) ? 1 : 0;
        $valid['comments_css_cleanup'] = (isset($input['comments_css_cleanup']) && !empty($input['comments_css_cleanup'])) ? 1: 0;
        $valid['gallery_css_cleanup'] = (isset($input['gallery_css_cleanup']) && !empty($input['gallery_css_cleanup'])) ? 1 : 0;
        $valid['body_class_slug'] = (isset($input['body_class_slug']) && !empty($input['body_class_slug'])) ? 1 : 0;
        $valid['jquery_cdn'] = (isset($input['jquery_cdn']) && !empty($input['jquery_cdn'])) ? 1 : 0;
        $valid['cdn_provider'] = esc_url($input['cdn_provider']);

        // Login Customization
        //First Color Picker
        $valid['login_background_color'] = (isset($input['login_background_color']) && !empty($input['login_background_color'])) ? sanitize_text_field($input['login_background_color']) : '';

        if ( !empty($valid['login_background_color']) && !preg_match( '/^#[a-f0-9]{6}$/i', $valid['login_background_color']  ) ) { // if user insert a HEX color with #
            add_settings_error(
                'login_background_color',                     // Setting title
                'login_background_color_texterror',            // Error ID
                'Please enter a valid hex value color',     // Error message
                'error'                         // Type of message
            );
        }

        //Second Color Picker
        $valid['login_button_primary_color'] = (isset($input['login_button_primary_color']) && !empty($input['login_button_primary_color'])) ? sanitize_text_field($input['login_button_primary_color']) : '';

        if ( !empty($valid['login_button_primary_color']) && !preg_match( '/^#[a-f0-9]{6}$/i', $valid['login_button_primary_color']  ) ) { // if user insert a HEX color with #
            add_settings_error(
                'login_button_primary_color',                     // Setting title
                'login_button_primary_color_texterror',            // Error ID
                'Please enter a valid hex value color',     // Error message
                'error'                         // Type of message
            );
        }

        //Logo image id
        $valid['login_logo_id'] = (isset($input['login_logo_id']) && !empty($input['login_logo_id'])) ? absint($input['login_logo_id']) : 0;


        return $valid;
    }

    public function render_settings_page()
    {
        require_once plugin_dir_path(__FILE__) . 'partials/leadify-settings-page.php';
    }
}
